==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/main/java/org/apache/webbeans/component/PrincipalBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.component;

import java.security.Principal;

import org.apache.webbeans.config.WebBeansContext;
import org.apache.webbeans.portable.ProviderBasedProducer;

public class PrincipalBean extends BuiltInOwbBean<Principal>
{

    public PrincipalBean(WebBeansContext webBeansContext)
    {
        super(webBeansContext,
              WebBeansType.PRINCIPAL,
              Principal.class,
              new SimpleProducerFactory<Principal>(new ProviderBasedProducer<Principal>(webBeansContext, Principal.class, new PrincipalProvider(webBeansContext), true)));
    }

    @Override
    public boolean isPassivationCapable()
    {
        return true;
    }

    @Override
    public Class<?> proxyableType()
    {
        return null;
    }
}

==> openwebbeans-2.0.4-source-release.zip: openwebbeans-2.0.4/webbeans-impl/src/main/java/org/apache/webbeans/component/PrincipalBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.component;

import java.security.Principal;

import org.apache.webbeans.config.WebBeansContext;
import org.apache.webbeans.portable.ProviderBasedProducer;

public class PrincipalBean extends BuiltInOwbBean<Principal>
{

    public PrincipalBean(WebBeansContext webBeansContext)
    {
        super(webBeansContext,
              WebBeansType.PRINCIPAL,
              Principal.class,
              new SimpleProducerFactory<>(new ProviderBasedProducer<>(webBeansContext, Principal.class, new PrincipalProvider(webBeansContext), true)));
    }

    @Override
    public boolean isPassivationCapable()
    {
        return true;
    }

    @Override
    public Class<?> proxyableType()
    {
        return null;
    }
}
